import setuptools

setuptools.setup(
    long_description="""
# PVMB

PVMB is the best message box package from pypi

## Installation


```bash
pip install pvmb
```

## Usage

```python

box("title", MB_ICONQUESTION | MB_CANCELTRYCONTINUE, "text")
```

## Message box mode list

### Mode

MB_ABORTRETRYIGNORE\n
MB_CANCELTRYCONTINUE\n
MB_HELP\n
MB_OK\n
MB_OKCANCEL\n
MB_RETRYCANCEL\n
MB_YESNO\n
MB_YESNOCANCEL\n
_________
### Icons

MB_ICONEXCLAMATION\n
MB_ICONWARNING\n
MB_ICONINFORMATION\n
MB_ICONASTERISK\n
MB_ICONQUESTION\n
MB_ICONSTOP\n
MB_ICONERROR\n
MB_ICONHAND
_____
### Buttons value

IDABORT = 3\n
IDCANCEL = 2\n
IDCONTINUE = 11\n
IDIGNORE = 5\n
IDNO = 7\n
IDOK = 1\n
IDRETRY = 4\n
IDTRYAGAIN = 10\n
IDYES = 6
___

### Highlighted button

MB_DEFBUTTON1\n
MB_DEFBUTTON2\n
MB_DEFBUTTON3\n
MB_DEFBUTTON4

#### Examples

```python
from foxbox import *
mybox = box("SOMETHING WEN WRONG. would you like to restart?",MB_DEFBUTTON1 | MB_ICONERROR | MB_YESNO, "ERROR!")
if mybox == IDYES:
    print('Restarted!')
if mybox == IDNO:
    print('Closed')
```

## Help

Thanks for use if you have any question join my Discord server link here [(--)](https:\discord.gg\c6twk26h)

## What's new?
v0.0.1 - first release\n""",
    long_description_content_type='text/markdown',
    name="PVMB",
    version='0.0.1',
    author="Batte",
    description="MessageBox package",
    packages=["src"]
)



import ctypes

MB_ABORTRETRYIGNORE = 2
MB_CANCELTRYCONTINUE = 6
MB_HELP = 0x4000
MB_OK = 0
MB_OKCANCEL = 1
MB_RETRYCANCEL = 5
MB_YESNO = 4
MB_YESNOCANCEL = 3

MB_ICONEXCLAMATION = MB_ICONWARNING = 0x30
MB_ICONINFORMATION = MB_ICONASTERISK = 0x40
MB_ICONQUESTION = 0x20
MB_ICONSTOP = MB_ICONERROR = MB_ICONHAND = 0x10

MB_DEFBUTTON1 = 0
MB_DEFBUTTON2 = 0x100
MB_DEFBUTTON3 = 0x200
MB_DEFBUTTON4 = 0x300

MB_APPLMODAL = 0
MB_SYSTEMMODAL = 0x1000
MB_TASKMODAL = 0x2000

MB_DEFAULT_DESKTOP_ONLY = 0x20000
MB_RIGHT = 0x80000
MB_RTLREADING = 0x100000

MB_SETFOREGROUND = 0x10000
MB_TOPMOST = 0x40000
MB_SERVICE_NOTIFICATION = 0x200000

IDABORT = 3
IDCANCEL = 2
IDCONTINUE = 11
IDIGNORE = 5
IDNO = 7
IDOK = 1
IDRETRY = 4
IDTRYAGAIN = 10
IDYES = 6

class box():
    def create(title, style, text):
        return ctypes.windll.user32.MessageBoxW(None, text, title, style)


box.create("Text", MB_ICONQUESTION | MB_RETRYCANCEL | MB_DEFBUTTON1, "Title")
